#!/bin/bash
#
# Convert rpm-info materials to new Publican formats, and copy
# to current directory.
#
# To use this script, first make your Publican document template,
# then 'cd' to that directory, copy the rpminfo-to-publican XSLT
# templates there, and run this script.  It takes one parameter,
# the directory in which your original document's rpm-info.xml
# resides.
#
#   $ rpminfo-to-publican.sh <DIR_WITH_rpm-info.xml>
#
# -- 
# (C) 2009 Paul W. Frields. This script is licensed under the GNU
# General Public License, version 2 or any later version.

print_usage() {
    echo "$(basename $0) [<DIR_WITH_rpm-info.xml> | <PATH_TO_rpm-info.xml>]"
}


if [ ! -f "Makefile" ]; then
    echo "Can't find Publican Makefile here in ${PWD}."
    exit 254
fi
for XSLT in rpminfo-to-publican-{templates,info,authorgroup,revhist}.xsl; do
    if [ ! -f "$XSLT" ]; then
	echo "Can't find ${XSLT} in this directory."
	exit 253
    fi
done

if [ -d "${1}" ]; then
    if [ -f "${1}/rpm-info.xml" ]; then
	RPMINFO="${1}/rpm-info.xml"
    fi
elif [ "`basename ${1}`" == "rpm-info.xml" ]; then
    RPMINFO="${1}"
else
    print_usage
    exit 252
fi

[ -z "$XSLTPROC" ] && XSLTPROC=`which xsltproc`
[ -z "$FRELEASE" ] && FRELEASE=10

# Get parameters
echo -n 'Grabbing parameters... '
PUB_PARAMS=`mktemp`; make help_params > $PUB_PARAMS
PUB_INTERNALS=`mktemp`; make help_internals > $PUB_INTERNALS
echo 'Done.'

# Set document type according to Publican params
PUB_DOC_TYPE=`cat "$PUB_PARAMS" | grep '^DOC_TYPE' | awk '{print $NF}'`
case $PUB_DOC_TYPE in
    'Book' )
	DOCTYPE="book" ;;
    'Article' )
	DOCTYPE="article" ;;
    'Set' ) 
	DOCTYPE="set" ;;
    * )
	echo "Document type unknown, defaulting to 'book'"
	DOCTYPE="book" ;;
esac

# Set document file name according to Makefile
DOCNAME=`cat "$PUB_INTERNALS" | grep '^DOCNAME' | awk '{print $NF}'`
DOCTITLE=`echo "$DOCNAME" | sed 's@_@ @'`

# Set language according to Makefile
XMLLANG=`cat "$PUB_PARAMS" | grep '^XML_LANG' | awk '{print $NF}'`

mkdir orig

cp "${XMLLANG}/${PUB_DOC_TYPE}_Info.xml" orig
"$XSLTPROC" \
    --stringparam doctype "$DOCTYPE" \
    --stringparam docfilename "$DOCNAME" \
    --stringparam doctitle "$DOCTITLE" \
    --stringparam prodrel "$FRELEASE" \
    rpminfo-to-publican-info.xsl "$RPMINFO" \
    > "${XMLLANG}/${PUB_DOC_TYPE}_Info.xml"

cp "${XMLLANG}/Author_Group.xml" orig
"$XSLTPROC" rpminfo-to-publican-authorgroup.xsl "$RPMINFO" \
    > "${XMLLANG}/Author_Group.xml"

cp "${XMLLANG}/Revision_History.xml" orig
"$XSLTPROC" rpminfo-to-publican-revhist.xsl "$RPMINFO" \
    > "${XMLLANG}/Revision_History.xml"

echo "Remember to add YEAR and HOLDER entities to ${XMLLANG}/${DOCNAME}.ent."
rm -f "$PUB_PARAMS" "$PUB_INTERNALS"
